@@ -30,7 +30,7 @@ func testGetWantedActionMetadata() *ActionMetadata {
 
 func TestLocalActionsFindMetadata(t *testing.T) {
 	proj := &Project{filepath.Join("testdata", "action_metadata"), nil}
-	c := NewLocalActionsCache(proj, nil)
+	c := NewLocalActionsCache(proj, "", nil)
 
 	want := testGetWantedActionMetadata()
 	for _, spec := range []string{"./action-yml", "./action-yaml"} {
@@ -81,7 +81,7 @@ func TestLocalActionsFindMetadata(t *testing.T) {
 func TestLocalActionsFindConcurrently(t *testing.T) {
 	n := 10
 	proj := &Project{filepath.Join("testdata", "action_metadata"), nil}
-	c := NewLocalActionsCache(proj, nil)
+	c := NewLocalActionsCache(proj, "", nil)
 	ret := make(chan *ActionMetadata)
 	err := make(chan error)
 
@@ -128,7 +128,7 @@ func TestLocalActionsFindConcurrently(t *testing.T) {
 }
 
 func TestLocalActionsProjectIsNil(t *testing.T) {
-	c := NewLocalActionsCache(nil, nil)
+	c := NewLocalActionsCache(nil, "", nil)
 	for _, spec := range []string{"./action-yml", "this-action-does-not-exit"} {
 		m, err := c.FindMetadata(spec)
 		if err != nil {
@@ -142,7 +142,7 @@ func TestLocalActionsProjectIsNil(t *testing.T) {
 
 func TestLocalActionsIgnoreRemoteActions(t *testing.T) {
 	proj := &Project{filepath.Join("testdata", "action_metadata"), nil}
-	c := NewLocalActionsCache(proj, nil)
+	c := NewLocalActionsCache(proj, "", nil)
 	for _, spec := range []string{"actions/checkout@v2", "docker://example.com/foo/bar"} {
 		m, err := c.FindMetadata(spec)
 		if err != nil {
@@ -157,7 +157,7 @@ func TestLocalActionsIgnoreRemoteActions(t *testing.T) {
 func TestLocalActionsLogCacheHit(t *testing.T) {
 	dbg := &bytes.Buffer{}
 	proj := &Project{filepath.Join("testdata", "action_metadata"), nil}
-	c := NewLocalActionsCache(proj, dbg)
+	c := NewLocalActionsCache(proj, "", dbg)
 
 	want := testGetWantedActionMetadata()
 	for i := 0; i < 2; i++ {
@@ -206,7 +206,7 @@ func TestLocalActionsFailures(t *testing.T) {
 
 	for _, tc := range testCases {
 		t.Run(tc.what, func(t *testing.T) {
-			c := NewLocalActionsCache(proj, nil)
+			c := NewLocalActionsCache(proj, "", nil)
 			m, err := c.FindMetadata(tc.spec)
 			if err == nil {
 				t.Fatal("error was not returned", m)
@@ -239,7 +239,7 @@ func TestLocalActionsFailures(t *testing.T) {
 func TestLocalActionsConcurrentFailures(t *testing.T) {
 	n := 10
 	proj := &Project{filepath.Join("testdata", "action_metadata"), nil}
-	c := NewLocalActionsCache(proj, nil)
+	c := NewLocalActionsCache(proj, "", nil)
 	errC := make(chan error)
 
 	for i := 0; i < n; i++ {
@@ -273,7 +273,7 @@ func TestLocalActionsConcurrentFailures(t *testing.T) {
 
 func TestLocalActionsConcurrentMultipleMetadataAndFailures(t *testing.T) {
 	proj := &Project{filepath.Join("testdata", "action_metadata"), nil}
-	c := NewLocalActionsCache(proj, nil)
+	c := NewLocalActionsCache(proj, "", nil)
 
 	inputs := []string{
 		"./action-yml",
@@ -490,14 +490,20 @@ outputs: "foo"`,
 }
 
 func TestLocalActionsCacheFactory(t *testing.T) {
-	f := NewLocalActionsCacheFactory(io.Discard)
+	f := NewLocalActionsCacheFactory("/path/to/dir", io.Discard)
 	p1 := &Project{"path/to/project1", nil}
 	c1 := f.GetCache(p1)
+
+	if c1.cwd != f.cwd {
+		t.Errorf("cwd %q is not propagated: %q", f.cwd, c1.cwd)
+	}
+
 	p2 := &Project{"path/to/project2", nil}
 	c2 := f.GetCache(p2)
 	if c1 == c2 {
 		t.Errorf("different cache was not created: %v", c1)
 	}
+
 	c3 := f.GetCache(p1)
 	if c1 != c3 {
 		t.Errorf("same cache is not returned for the same project: %v vs %v", c1, c3)
