@@ -356,8 +356,6 @@ const (
 type Exec interface {
 	// Kind returns kind of the step execution.
 	Kind() ExecKind
-	// SetWorkingDir sets working-directory section.
-	SetWorkingDir(d *String)
 }
 
 // ExecRun is configuration how to run shell script at the step.
@@ -378,11 +376,6 @@ func (e *ExecRun) Kind() ExecKind {
 	return ExecKindRun
 }
 
-// SetWorkingDir sets working-directory section.
-func (e *ExecRun) SetWorkingDir(dir *String) {
-	e.WorkingDirectory = dir
-}
-
 // Input is an input field for running an action.
 // https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#jobsjob_idstepswith
 type Input struct {
@@ -405,8 +398,6 @@ type ExecAction struct {
 	// Args represents optional 'args' field in 'with' section. Nil field means nothing specified
 	// https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#jobsjob_idstepswithargs
 	Args *String
-	// WorkingDirectory is a default working directory path to run action
-	WorkingDirectory *String
 }
 
 // Kind returns kind of the step execution.
@@ -414,11 +405,6 @@ func (e *ExecAction) Kind() ExecKind {
 	return ExecKindAction
 }
 
-// SetWorkingDir sets working-directory section.
-func (e *ExecAction) SetWorkingDir(dir *String) {
-	e.WorkingDirectory = dir
-}
-
 // RawYAMLValueKind is kind of raw YAML values
 type RawYAMLValueKind int
 
