@@ -694,6 +694,7 @@ func TestExprSemanticsCheckError(t *testing.T) {
 		matrix   *ObjectType
 		steps    *ObjectType
 		needs    *ObjectType
+		noEnv    bool
 	}{
 		{
 			what:  "undefined variable",
@@ -1060,6 +1061,14 @@ func TestExprSemanticsCheckError(t *testing.T) {
 				"property \"hello\" is not defined in object type {}",
 			},
 		},
+		{
+			what:  "'env' context is not allowed",
+			input: "env.FOO",
+			expected: []string{
+				"undefined variable \"env\"",
+			},
+			noEnv: true,
+		},
 	}
 
 	for _, tc := range testCases {
@@ -1083,6 +1092,9 @@ func TestExprSemanticsCheckError(t *testing.T) {
 			if tc.needs != nil {
 				c.UpdateNeeds(tc.needs)
 			}
+			if tc.noEnv {
+				c.NoEnv()
+			}
 			_, errs := c.Check(e)
 			if len(errs) != len(tc.expected) {
 				t.Fatalf("semantics check should report %d errors but got %d errors %#v", len(tc.expected), len(errs), errs)
@@ -1141,6 +1153,13 @@ func TestExprSematincsCheckerUpdateDispatchInputsVarType(t *testing.T) {
 	if !o.IsStrict() {
 		t.Error("Local github.event.inputs is not strict")
 	}
+	for n, ty := range o.Props {
+		if _, ok := ty.(StringType); !ok {
+			t.Errorf("Type of %q input is not string: %s", n, ty)
+		}
+	}
+
+	// Check global value is not polluted
 	o = BuiltinGlobalVariableTypes["github"].(*ObjectType).Props["event"].(*ObjectType)
 	if _, ok := o.Props["inputs"]; ok {
 		t.Error("Global github.event.inputs exists", o)
