@@ -94,6 +94,44 @@ func testFindAllWorkflowsInDir(subdir string) (string, []string, error) {
 	return dir, fs, nil
 }
 
+func checkErrors(t *testing.T, outfile string, errs []*Error) {
+	expected := []string{}
+	{
+		f, err := os.Open(outfile)
+		if err != nil {
+			panic(err)
+		}
+		s := bufio.NewScanner(f)
+		for s.Scan() {
+			expected = append(expected, s.Text())
+		}
+		if err := s.Err(); err != nil {
+			panic(err)
+		}
+	}
+
+	if len(errs) != len(expected) {
+		t.Fatalf("%d errors are expected but actually got %d errors: %# v", len(expected), len(errs), errs)
+	}
+
+	sort.Sort(ByErrorPosition(errs))
+
+	for i := 0; i < len(errs); i++ {
+		errs[i].Filepath = filepath.ToSlash(errs[i].Filepath) // For Windows
+		want, have := expected[i], errs[i].Error()
+		if strings.HasPrefix(want, "/") && strings.HasSuffix(want, "/") {
+			want := regexp.MustCompile(want[1 : len(want)-1])
+			if !want.MatchString(have) {
+				t.Errorf("error message mismatch at %dth error does not match to regular expression\n  want: /%s/\n  have: %q", i+1, want, have)
+			}
+		} else {
+			if want != have {
+				t.Errorf("error message mismatch at %dth error does not match exactly\n  want: %q\n  have: %q", i+1, want, have)
+			}
+		}
+	}
+}
+
 func TestLinterLintError(t *testing.T) {
 	for _, subdir := range []string{"examples", "err"} {
 		dir, infiles, err := testFindAllWorkflowsInDir(subdir)
@@ -103,9 +141,18 @@ func TestLinterLintError(t *testing.T) {
 
 		proj := &Project{root: dir}
 
+		shellcheck := ""
+		if p, err := execabs.LookPath("shellcheck"); err == nil {
+			shellcheck = p
+		}
+
+		pyflakes := ""
+		if p, err := execabs.LookPath("pyflakes"); err == nil {
+			pyflakes = p
+		}
+
 		for _, infile := range infiles {
 			base := strings.TrimSuffix(infile, filepath.Ext(infile))
-			outfile := base + ".out"
 			testName := filepath.Base(base)
 			t.Run(subdir+"/"+testName, func(t *testing.T) {
 				b, err := os.ReadFile(infile)
@@ -116,19 +163,17 @@ func TestLinterLintError(t *testing.T) {
 				opts := LinterOptions{}
 
 				if strings.Contains(testName, "shellcheck") {
-					p, err := execabs.LookPath("shellcheck")
-					if err != nil {
+					if shellcheck == "" {
 						t.Skip("skipped because \"shellcheck\" command does not exist in system")
 					}
-					opts.Shellcheck = p
+					opts.Shellcheck = shellcheck
 				}
 
 				if strings.Contains(testName, "pyflakes") {
-					p, err := execabs.LookPath("pyflakes")
-					if err != nil {
+					if pyflakes == "" {
 						t.Skip("skipped because \"pyflakes\" command does not exist in system")
 					}
-					opts.Pyflakes = p
+					opts.Pyflakes = pyflakes
 				}
 
 				linter, err := NewLinter(io.Discard, &opts)
@@ -139,50 +184,54 @@ func TestLinterLintError(t *testing.T) {
 				config := Config{}
 				linter.defaultConfig = &config
 
-				expected := []string{}
-				{
-					f, err := os.Open(outfile)
-					if err != nil {
-						panic(err)
-					}
-					s := bufio.NewScanner(f)
-					for s.Scan() {
-						expected = append(expected, s.Text())
-					}
-					if err := s.Err(); err != nil {
-						panic(err)
-					}
-				}
-
 				errs, err := linter.Lint("test.yaml", b, proj)
 				if err != nil {
 					t.Fatal(err)
 				}
 
-				if len(errs) != len(expected) {
-					t.Fatalf("%d errors are expected but actually got %d errors: %# v", len(expected), len(errs), errs)
-				}
-
-				sort.Sort(ByErrorPosition(errs))
-
-				for i := 0; i < len(errs); i++ {
-					want, have := expected[i], errs[i].Error()
-					if strings.HasPrefix(want, "/") && strings.HasSuffix(want, "/") {
-						want := regexp.MustCompile(want[1 : len(want)-1])
-						if !want.MatchString(have) {
-							t.Errorf("error message mismatch at %dth error does not match to regular expression\n  want: /%s/\n  have: %q", i+1, want, have)
-						}
-					} else {
-						if want != have {
-							t.Errorf("error message mismatch at %dth error does not match exactly\n  want: %q\n  have: %q", i+1, want, have)
-						}
-					}
-				}
+				checkErrors(t, base+".out", errs)
 			})
 		}
 	}
 }
 
+func TestLinterLintProjectError(t *testing.T) {
+	root := filepath.Join("testdata", "err", "projects")
+	entries, err := os.ReadDir(root)
+	if err != nil {
+		panic(err)
+	}
+
+	for _, info := range entries {
+		if !info.IsDir() {
+			continue
+		}
+
+		name := info.Name()
+		t.Run("err/"+name, func(t *testing.T) {
+			repo := filepath.Join(root, name)
+			opts := LinterOptions{
+				WorkingDir: repo,
+			}
+			linter, err := NewLinter(io.Discard, &opts)
+			if err != nil {
+				t.Fatal(err)
+			}
+
+			config := Config{}
+			linter.defaultConfig = &config
+
+			proj := &Project{root: repo}
+			errs, err := linter.LintDir(filepath.Join(repo, "workflows"), proj)
+			if err != nil {
+				t.Fatal(err)
+			}
+
+			checkErrors(t, repo+".out", errs)
+		})
+	}
+}
+
 func TestLinterFormatErrorMessageOK(t *testing.T) {
 	tests := []struct {
 		file   string
