@@ -114,7 +114,7 @@ func (p *parser) checkString(n *yaml.Node, allowEmpty bool) bool {
 }
 
 func (p *parser) missingExpression(n *yaml.Node, expecting string) {
-	p.errorf(n, "expecting a string with ${{...}} expression or %s, but found plain text node", expecting)
+	p.errorf(n, "expecting a single ${{...}} expression or %s, but found plain text node", expecting)
 }
 
 func (p *parser) parseExpression(n *yaml.Node, expecting string) *String {
@@ -123,7 +123,7 @@ func (p *parser) parseExpression(n *yaml.Node, expecting string) *String {
 		p.missingExpression(n, expecting)
 		return nil
 	}
-	if strings.Count(n.Value, "${{") != 1 || strings.Count(n.Value, "}}") != 1 {
+	if strings.Count(n.Value, "${{") != 1 {
 		p.missingExpression(n, expecting)
 		return nil
 	}
@@ -135,7 +135,7 @@ func (p *parser) mayParseExpression(n *yaml.Node) *String {
 		return nil
 	}
 	s := strings.TrimSpace(n.Value)
-	if !strings.HasPrefix(s, "${{") || !strings.HasSuffix(s, "}}") || strings.Count(n.Value, "${{") != 1 || strings.Count(n.Value, "}}") != 1 {
+	if !strings.HasPrefix(s, "${{") || !strings.HasSuffix(s, "}}") || strings.Count(n.Value, "${{") != 1 {
 		return nil
 	}
 	return newString(n)
@@ -277,7 +277,7 @@ func (p *parser) parseMapping(what string, n *yaml.Node, allowEmpty bool) []keyV
 		k.Value = strings.ToLower(k.Value)
 
 		if pos, ok := keys[k.Value]; ok {
-			p.errorfAt(k.Pos, "key %q is duplicate in %s. previously defined at %s. note that key names are case insensitive", k.Value, what, pos.String())
+			p.errorfAt(k.Pos, "key %q is duplicated in %s. previously defined at %s. note that key names are case insensitive", k.Value, what, pos.String())
 			continue
 		}
 		m = append(m, keyVal{k, n.Content[i+1]})
@@ -997,7 +997,6 @@ func (p *parser) parseStep(n *yaml.Node) *Step {
 					}
 				}
 			}
-			exec.WorkingDirectory = workDir
 			ret.Exec = exec
 		case "run", "shell":
 			var exec *ExecRun
@@ -1020,8 +1019,8 @@ func (p *parser) parseStep(n *yaml.Node) *Step {
 			ret.Exec = exec
 		case "working-directory":
 			workDir = p.parseString(kv.val, false)
-			if ret.Exec != nil {
-				ret.Exec.SetWorkingDir(workDir)
+			if e, ok := ret.Exec.(*ExecRun); ok {
+				e.WorkingDirectory = workDir
 			}
 		default:
 			p.unexpectedKey(kv.key, "step", []string{
@@ -1045,6 +1044,9 @@ func (p *parser) parseStep(n *yaml.Node) *Step {
 		if e.Uses == nil {
 			p.error(n, "\"uses\" is required to run action in step")
 		}
+		if workDir != nil {
+			p.errorAt(workDir.Pos, "\"working-directory\" is not available with \"uses\". it is only available with \"run\"")
+		}
 	case *ExecRun:
 		if e.Run == nil {
 			p.error(n, "\"run\" is required to run script in step")
@@ -1141,7 +1143,6 @@ func (p *parser) parseJob(id *String, n *yaml.Node) *Job {
 			stepsOnlyKey = k
 		case "strategy":
 			ret.Strategy = p.parseStrategy(k.Pos, v)
-			stepsOnlyKey = k
 		case "continue-on-error":
 			ret.ContinueOnError = p.parseBool(v)
 			stepsOnlyKey = k
